# Class: PVS&#95;proxy

a proxy connects a VM/VIF with a PVS site

## Fields for class: PVS&#95;proxy

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|`currently_attached`|`bool`              |_RO/runtime_   |true = VM is currently proxied          |
|`site`              |`PVS_site ref`      |_RO/constructor_|PVS site this proxy is part of          |
|`status`            |`pvs_proxy_status`  |_RO/runtime_   |The run&#45;time status of the proxy    |
|`uuid`              |`string`            |_RO/runtime_   |Unique identifier/object reference      |
|`VIF`               |`VIF ref`           |_RO/constructor_|VIF of the VM using the proxy           |

## RPCs associated with class: PVS&#95;proxy

### RPC name: create

_Overview:_

Configure a VM/VIF to use a PVS proxy

_Signature:_

```
PVS_proxy ref create (session ref session_ref, PVS_site ref site, VIF ref VIF)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PVS_site ref`                |`site`                        |PVS site that we proxy for              |
|`VIF ref`                     |`VIF`                         |VIF for the VM that needs to be proxied |

_Minimum Role:_ pool-operator

_Return Type:_ `PVS_proxy ref`

The reference of the created PVS proxy

### RPC name: destroy

_Overview:_

remove &#40;or switch off&#41; a PVS proxy for this VM

_Signature:_

```
void destroy (session ref session_ref, PVS_proxy ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PVS_proxy ref`               |`self`                        |this PVS proxy                          |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

### RPC name: get&#95;all

_Overview:_

Return a list of all the PVS&#95;proxys known to the system.

_Signature:_

```
PVS_proxy ref set get_all (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `PVS_proxy ref set`

references to all objects

### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of PVS&#95;proxy references to PVS&#95;proxy records for all PVS&#95;proxys known to the system.

_Signature:_

```
(PVS_proxy ref -> PVS_proxy record) map get_all_records (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `(PVS_proxy ref -> PVS_proxy record) map`

records of all objects

### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the PVS&#95;proxy instance with the specified UUID.

_Signature:_

```
PVS_proxy ref get_by_uuid (session ref session_ref, string uuid)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`uuid`                        |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `PVS_proxy ref`

reference to the object

### RPC name: get&#95;currently&#95;attached

_Overview:_

Get the currently&#95;attached field of the given PVS&#95;proxy.

_Signature:_

```
bool get_currently_attached (session ref session_ref, PVS_proxy ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PVS_proxy ref`               |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given PVS&#95;proxy.

_Signature:_

```
PVS_proxy record get_record (session ref session_ref, PVS_proxy ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PVS_proxy ref`               |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PVS_proxy record`

all fields from the object

### RPC name: get&#95;site

_Overview:_

Get the site field of the given PVS&#95;proxy.

_Signature:_

```
PVS_site ref get_site (session ref session_ref, PVS_proxy ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PVS_proxy ref`               |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PVS_site ref`

value of the field

### RPC name: get&#95;status

_Overview:_

Get the status field of the given PVS&#95;proxy.

_Signature:_

```
pvs_proxy_status get_status (session ref session_ref, PVS_proxy ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PVS_proxy ref`               |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `pvs_proxy_status`

value of the field

### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given PVS&#95;proxy.

_Signature:_

```
string get_uuid (session ref session_ref, PVS_proxy ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PVS_proxy ref`               |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;VIF

_Overview:_

Get the VIF field of the given PVS&#95;proxy.

_Signature:_

```
VIF ref get_VIF (session ref session_ref, PVS_proxy ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`PVS_proxy ref`               |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VIF ref`

value of the field
